==> paraview-v1.0.0.zip: paraview-v1.0.0/ParaView/ParaView/vtkPVMultiDisplayPartDisplay.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVMultiDisplayPartDisplay.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkPVMultiDisplayPartDisplay - For tiled diplay (what on client).
// .SECTION Description
// This class has an unfortunate name ...  It always collects and displays
// the LOD on node zero (client when we enable client server).

#ifndef __vtkPVMultiDisplayPartDisplay_h
#define __vtkPVMultiDisplayPartDisplay_h

#include "vtkPVCompositePartDisplay.h"


class VTK_EXPORT vtkPVMultiDisplayPartDisplay : public vtkPVCompositePartDisplay
{
public:
  static vtkPVMultiDisplayPartDisplay* New();
  vtkTypeRevisionMacro(vtkPVMultiDisplayPartDisplay, vtkPVCompositePartDisplay);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Override super class so that the LOD is always collected.
  virtual void SetLODCollectionDecision(int val);
    
protected:
  vtkPVMultiDisplayPartDisplay();
  ~vtkPVMultiDisplayPartDisplay();
  
  // Description:
  // This method should be called immediately after the object is constructed.
  // It create VTK objects which have to exeist on all processes.
  virtual void CreateParallelTclObjects(vtkPVApplication *pvApp);

  vtkPVMultiDisplayPartDisplay(const vtkPVMultiDisplayPartDisplay&); // Not implemented
  void operator=(const vtkPVMultiDisplayPartDisplay&); // Not implemented
};

#endif

==> paraview-v1.2.0.zip: paraview-v1.2.0/ParaView/ParaView/vtkPVMultiDisplayPartDisplay.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVMultiDisplayPartDisplay.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPVMultiDisplayPartDisplay - For tiled diplay (what on client).
// .SECTION Description
// This class has an unfortunate name ...  It always collects and displays
// the LOD on node zero (client when we enable client server).

#ifndef __vtkPVMultiDisplayPartDisplay_h
#define __vtkPVMultiDisplayPartDisplay_h

#include "vtkPVCompositePartDisplay.h"


class VTK_EXPORT vtkPVMultiDisplayPartDisplay : public vtkPVCompositePartDisplay
{
public:
  static vtkPVMultiDisplayPartDisplay* New();
  vtkTypeRevisionMacro(vtkPVMultiDisplayPartDisplay, vtkPVCompositePartDisplay);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Override super class so that the LOD is always collected.
  virtual void SetLODCollectionDecision(int val);
    
  // Description:
  // Update like normal, but make sure the LOD is collected.
  // I encountered a bug. First render was missing the LOD on the client.
  void Update();
  
protected:
  vtkPVMultiDisplayPartDisplay();
  ~vtkPVMultiDisplayPartDisplay();
  
  // Description:
  // This method should be called immediately after the object is constructed.
  // It create VTK objects which have to exeist on all processes.
  virtual void CreateParallelTclObjects(vtkPVApplication *pvApp);

  vtkPVMultiDisplayPartDisplay(const vtkPVMultiDisplayPartDisplay&); // Not implemented
  void operator=(const vtkPVMultiDisplayPartDisplay&); // Not implemented
};

#endif
